SyntaxOperator

Struct SyntaxOperator 

pub struct SyntaxOperator(/* private fields */);
Defines the different operators allowed within a regex syntax.

Implementations

Source

impl SyntaxOperator

pub const SYNTAX_OPERATOR_DOT_ANYCHAR: Self

.

pub const SYNTAX_OPERATOR_ASTERISK_ZERO_INF: Self

*

pub const SYNTAX_OPERATOR_PLUS_ONE_INF: Self

+

pub const SYNTAX_OPERATOR_QMARK_ZERO_ONE: Self

?

pub const SYNTAX_OPERATOR_QMARK_CAPITAL_P_NAME: Self

?P

pub const SYNTAX_OPERATOR_BRACE_INTERVAL: Self

{lower,upper}

pub const SYNTAX_OPERATOR_ESC_BRACE_INTERVAL: Self

\{lower,upper\}

pub const SYNTAX_OPERATOR_VBAR_ALT: Self

|

pub const SYNTAX_OPERATOR_ESC_VBAR_ALT: Self

\|

pub const SYNTAX_OPERATOR_LPAREN_SUBEXP: Self

(...)

pub const SYNTAX_OPERATOR_ESC_LPAREN_SUBEXP: Self

\(...\)

pub const SYNTAX_OPERATOR_ESC_AZ_BUF_ANCHOR: Self

\A, \Z, \z

pub const SYNTAX_OPERATOR_ESC_CAPITAL_G_BEGIN_ANCHOR: Self

\G

pub const SYNTAX_OPERATOR_DECIMAL_BACKREF: Self

\num

pub const SYNTAX_OPERATOR_BRACKET_CC: Self

[...]

pub const SYNTAX_OPERATOR_ESC_W_WORD: Self

\w, \W

pub const SYNTAX_OPERATOR_ESC_LTGT_WORD_BEGIN_END: Self

\<. \>

pub const SYNTAX_OPERATOR_ESC_B_WORD_BOUND: Self

\b, \B

pub const SYNTAX_OPERATOR_ESC_S_WHITE_SPACE: Self

\s, \S

pub const SYNTAX_OPERATOR_ESC_D_DIGIT: Self

\d, \D

pub const SYNTAX_OPERATOR_LINE_ANCHOR: Self

^, $

pub const SYNTAX_OPERATOR_POSIX_BRACKET: Self

[:xxxx:]

pub const SYNTAX_OPERATOR_QMARK_NON_GREEDY: Self

??,*?,+?,{n,m}?

pub const SYNTAX_OPERATOR_ESC_CONTROL_CHARS: Self

\n,\r,\t,\a ...

pub const SYNTAX_OPERATOR_ESC_C_CONTROL: Self

\cx

pub const SYNTAX_OPERATOR_ESC_OCTAL3: Self

\OOO

pub const SYNTAX_OPERATOR_ESC_X_HEX2: Self

\xHH

pub const SYNTAX_OPERATOR_ESC_X_BRACE_HEX8: Self

\x{7HHHHHHH}

pub const SYNTAX_OPERATOR_VARIABLE_META_CHARACTERS: Self

Variable meta characters

pub const SYNTAX_OPERATOR_ESC_CAPITAL_Q_QUOTE: Self

\Q...\E

pub const SYNTAX_OPERATOR_QMARK_GROUP_EFFECT: Self

(?...)

pub const SYNTAX_OPERATOR_OPTION_PERL: Self

(?imsx),(?-imsx)

pub const SYNTAX_OPERATOR_OPTION_RUBY: Self

(?imx), (?-imx)

pub const SYNTAX_OPERATOR_PLUS_POSSESSIVE_REPEAT: Self

?+,*+,++

pub const SYNTAX_OPERATOR_PLUS_POSSESSIVE_INTERVAL: Self

{n,m}+

pub const SYNTAX_OPERATOR_CCLASS_SET_OP: Self

[...&&..[..]..]

pub const SYNTAX_OPERATOR_QMARK_LT_NAMED_GROUP: Self

(?<name>...)

pub const SYNTAX_OPERATOR_ESC_K_NAMED_BACKREF: Self

\k<name>

pub const SYNTAX_OPERATOR_ESC_G_SUBEXP_CALL: Self

\g<name>, \g<n>

pub const SYNTAX_OPERATOR_ATMARK_CAPTURE_HISTORY: Self

(?@..),(?@<x>..)

pub const SYNTAX_OPERATOR_ESC_CAPITAL_C_BAR_CONTROL: Self

\C-x

pub const SYNTAX_OPERATOR_ESC_CAPITAL_M_BAR_META: Self

\M-x

pub const SYNTAX_OPERATOR_ESC_V_VTAB: Self

\v as VTAB

pub const SYNTAX_OPERATOR_ESC_U_HEX4: Self

\uHHHH

pub const SYNTAX_OPERATOR_ESC_GNU_BUF_ANCHOR: Self

\, '`

pub const SYNTAX_OPERATOR_ESC_P_BRACE_CHAR_PROPERTY: Self

\p{...}, \P{...}

pub const SYNTAX_OPERATOR_ESC_P_BRACE_CIRCUMFLEX_NOT: Self

\p{^..}, \P{^..}

pub const SYNTAX_OPERATOR_ESC_H_XDIGIT: Self

\h, \H

pub const SYNTAX_OPERATOR_INEFFECTIVE_ESCAPE: Self

\

Source

impl SyntaxOperator

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl SyntaxOperator

pub const fn iter(&self) -> Iter<SyntaxOperator>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<SyntaxOperator>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.