pub enum RegSetLead {
Position,
Regex,
PriorityToRegexOrder,
}Expand description
Defines the search priority when multiple regexes could match at the same position
Variants
Position
Return the match that occurs first in the text (position priority)
Regex
Same results as Position I think but slower
PriorityToRegexOrder
Return the first regex in your regset that matches, regardless of position